# This scripts prepares and saves the `endothelial` data.

args <- R.utils::commandArgs(
  trailingOnly = TRUE,
  asValues = TRUE
)

suppressMessages({
  library(scater)
  library(scran)
  library(Seurat)
})

set.seed(08082021)

endothelial <- readRDS(args$raw_data)

# Remove unneeded assays which prevent conversion to a SCE object.
endothelial@assays$HTO <- NULL
endothelial@assays$SCT <- NULL

endothelial <- as.SingleCellExperiment(endothelial)

rowData(endothelial) <- DataFrame(gene = rownames(endothelial))

colData(endothelial)$predicted.id <- factor(colData(endothelial)$predicted.id)
colLabels(endothelial) <- colData(endothelial)$predicted.id

clusters <- quickCluster(endothelial)
endothelial <- computeSumFactors(endothelial, clusters = clusters)
endothelial <- logNormCounts(endothelial)

dec_endothelial <- modelGeneVarByPoisson(endothelial)
top_endothelial <- getTopHVGs(dec_endothelial, n = 5000)
endothelial <- endothelial[top_endothelial, ]

saveRDS(endothelial, args$data)
