#' Find marker genes using cepo
#'
#' @param sce A SingleCellExperiment object,
#' @param pars A list of parameters passed to the function. The empty list.
#'
#' @return A list containing the time of the computation and results of the
#'  method.
#'
run_cepo <- function(sce, pars) {
  
  times <- system.time({
    # minCells must be lower than 20, to account for e.g. the Platelet cluster
    # in the pbmc3k dataset.
    cepo_out <- Cepo::Cepo(
      exprsMat = logcounts(sce),
      cellTypes = colLabels(sce),
      minCells = 2
    )
    marker_genes <- Cepo::topGenes(cepo_out, n = 200, returnValues = TRUE)
  })
 
  result <- purrr::imap(marker_genes, ~ 
    tibble::tibble(gene = names(.x), value = .x) |> 
      dplyr::mutate(cluster = .y)
  ) |> 
    dplyr::bind_rows()
 
  result <- dplyr::rename(result, raw_statistic = value)
   
  result <- dplyr::mutate(
    result,
    log_fc = 0,
    scaled_statistic = 0,
    p_value = 0,
    p_value_adj = 0
  )
  
  # Get the elapsed time.
  time <- times[[3]]
  
  validate_mgs_result(result)
  
  list(time = time, result = result, raw_result = marker_genes, pars = pars)
}
